<?php
require(get_template_directory() .'/functions/comments.php');
//require(get_template_directory() .'/functions/widgets/about.php');

/**
* Adds support for a theme option.
*/
if ( !function_exists( 'optionsframework_init' ) ) {
	define('OPTIONS_FRAMEWORK_URL', get_template_directory() . '/inc/');
	define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
	require_once (OPTIONS_FRAMEWORK_URL . 'options-framework.php');
}

if ( !function_exists( 'of_get_option' ) ) {
function of_get_option($name, $default = false) {
	$optionsframework_settings = get_option('optionsframework');
	// Gets the unique option id
	$option_name = $optionsframework_settings['id'];
	if ( get_option($option_name) ) {
		$options = get_option($option_name);
	}
	if ( isset($options[$name]) ) {
		return $options[$name];
	} else {
		return $default;
	}
}
}

// Theme Setup
function perfection_setup() {
	
	add_theme_support( 'automatic-feed-links' );
	
	// Featured Image
	add_theme_support( 'post-thumbnails' );

	set_post_thumbnail_size( 125, 125, true ); 
	
	global $content_width;
	if (!isset($content_width)) $content_width = 615;

	//Menu 
	register_nav_menu('top-nav', 'Top Navigation');
	register_nav_menu('main-nav', 'Main Navigation');
	
    add_editor_style( 'styles/editor-style.css' );

}
add_action( 'after_setup_theme', 'perfection_setup' );

# Enqueues all scripts and styles for front end.
function perfection_scripts_styles() {

	// Add js support for pages with commenting enabled.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) wp_enqueue_script('comment-reply');
	
	wp_enqueue_script('thickbox');
	wp_enqueue_script('superfish', get_template_directory_uri().'/js/jquery.superfish.js', array('jquery'), '1.0');
	wp_enqueue_script('custom-js', get_template_directory_uri().'/js/custom.js', array('jquery'), '1.0');
		
	wp_enqueue_style('thickbox');
}
add_action( 'wp_enqueue_script', 'perfection_scripts_styles' );


# Displays navigation to next/previous post when applicable.
function perfection_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<div class="navigation post-navigation" role="navigation">
		<div class="nav-links">
			<div class="previous-entry"><?php previous_post_link( '%link', '<span class="meta-nav">&larr;</span> %title', 'Previous post link' ); ?></div>
			<div class="next-entry"><?php next_post_link( '%link', '%title <span class="meta-nav">&rarr;</span>', 'Next post link' ); ?></div>

		</div><!-- .nav-links -->
	</div><!-- .navigation -->
	<?php
}

function perfection_wp_title($sep) {
	if ( is_single() || is_page() ) {
		$title = single_post_title('', false);
	} elseif ( is_home() || is_front_page() ) {
		$title = get_bloginfo('name') . " | " . get_bloginfo('description');
	} elseif ( is_search() ) {
		$title = get_bloginfo('name') . " | Search results";
	} elseif ( is_404() ) {
		$title = get_bloginfo('name') . " | Not Found";
	} else {
		$title = get_bloginfo('name');// . wp_title('|', false);
	}
	return $title;
}
add_filter( 'wp_title', 'perfection_wp_title', 10, 2 );

function perfection_widgets() {

	// Register widget area: Home Sidebar
	register_sidebar(array(
		'name'          => 'Sidebar Widgets',
		'id'            => 'sidebar-widgets',
		'before_widget' => '<div class="widget clearfix %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4>',
	));

	// Register widget area: Home Sidebar
	register_sidebar(array(
		'name'          => 'Footer Widgets',
		'id'            => 'footer-widgets',
		'before_widget' => '<div class="widget clearfix %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'  => '</h4>',
	));
}
add_action('widgets_init', 'perfection_widgets');

?>